BUPA Liver Disorders Data Base

# Info on BUPA Liver Disorders Data Base

    1. Title: BUPA liver disorders

    2. Source information:
       -- Creators: BUPA Medical Research Ltd.
       -- Donor: Richard S. Forsyth
                 8 Grosvenor Avenue
                 Mapperley Park
                 Nottingham NG3 5DX
                 0602-621676
       -- Date: 5/15/1990

    3. Past usage:
       -- None known other than what is shown in the PC/BEAGLE User's Guide
          (written by Richard S. Forsyth).

    4. Relevant information:
       -- The first 5 variables are all blood tests which are thought
          to be sensitive to liver disorders that might arise from
          excessive alcohol consumption.  Each line in the bupa.data file
          constitutes the record of a single male individual.
       -- It appears that drinks>5 is some sort of a selector on this database.
          See the PC/BEAGLE User's Guide for more information.

    5. Number of instances: 345

    6. Number of attributes: 7 overall

    7. Attribute information:
       1. mcv	mean corpuscular volume
       2. alkphos	alkaline phosphotase
       3. sgpt	alamine aminotransferase
       4. sgot 	aspartate aminotransferase
       5. gammagt	gamma-glutamyl transpeptidase
       6. drinks	number of half-pint equivalents of alcoholic beverages
                    drunk per day
       7. selector  field used to split data into two sets

    8. Missing values: none